@@ -2,14 +2,22 @@
 // See the COPYRIGHT file at the top-level directory of this distribution.
 // Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>
 
+use gdk_sys;
 use glib::translate::*;
-use ffi;
 
 #[derive(Clone, Debug, PartialEq, Eq, PartialOrd, Ord, Hash)]
 pub struct EventDND(::Event);
 
 event_wrapper!(EventDND, GdkEventDND);
-event_subtype!(EventDND, ffi::GDK_DRAG_ENTER | ffi::GDK_DRAG_LEAVE | ffi::GDK_DRAG_MOTION | ffi::GDK_DRAG_STATUS | ffi::GDK_DROP_START | ffi::GDK_DROP_FINISHED);
+event_subtype!(
+    EventDND,
+    gdk_sys::GDK_DRAG_ENTER
+        | gdk_sys::GDK_DRAG_LEAVE
+        | gdk_sys::GDK_DRAG_MOTION
+        | gdk_sys::GDK_DRAG_STATUS
+        | gdk_sys::GDK_DROP_START
+        | gdk_sys::GDK_DROP_FINISHED
+);
 
 impl EventDND {
     pub fn get_context(&self) -> Option<::DragContext> {
