@@ -2,14 +2,17 @@
 // See the COPYRIGHT file at the top-level directory of this distribution.
 // Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>
 
+use gdk_sys;
 use glib::translate::*;
-use ffi;
 
 #[derive(Clone, Debug, PartialEq, Eq, PartialOrd, Ord, Hash)]
 pub struct EventSelection(::Event);
 
 event_wrapper!(EventSelection, GdkEventSelection);
-event_subtype!(EventSelection, ffi::GDK_SELECTION_CLEAR | ffi::GDK_SELECTION_NOTIFY | ffi::GDK_SELECTION_REQUEST);
+event_subtype!(
+    EventSelection,
+    gdk_sys::GDK_SELECTION_CLEAR | gdk_sys::GDK_SELECTION_NOTIFY | gdk_sys::GDK_SELECTION_REQUEST
+);
 
 impl EventSelection {
     pub fn get_selection(&self) -> ::Atom {
