@@ -2,14 +2,14 @@
 // See the COPYRIGHT file at the top-level directory of this distribution.
 // Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>
 
+use gdk_sys;
 use glib::translate::*;
-use ffi;
 
 #[derive(Clone, Debug, PartialEq, Eq, PartialOrd, Ord, Hash)]
 pub struct EventVisibility(::Event);
 
 event_wrapper!(EventVisibility, GdkEventVisibility);
-event_subtype!(EventVisibility, ffi::GDK_VISIBILITY_NOTIFY);
+event_subtype!(EventVisibility, gdk_sys::GDK_VISIBILITY_NOTIFY);
 
 impl EventVisibility {
     pub fn get_state(&self) -> ::VisibilityState {
