@@ -2,14 +2,14 @@
 // See the COPYRIGHT file at the top-level directory of this distribution.
 // Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>
 
+use gdk_sys;
 use glib::translate::*;
-use ffi;
 
 #[derive(Clone, Debug, PartialEq, Eq, PartialOrd, Ord, Hash)]
 pub struct EventWindowState(::Event);
 
 event_wrapper!(EventWindowState, GdkEventWindowState);
-event_subtype!(EventWindowState, ffi::GDK_WINDOW_STATE);
+event_subtype!(EventWindowState, gdk_sys::GDK_WINDOW_STATE);
 
 impl EventWindowState {
     pub fn get_changed_mask(&self) -> ::WindowState {
