@@ -4,11 +4,6 @@
 
 //! Traits intended for blanket imports.
 
-pub use cairo_interaction::ContextExt;
 pub use auto::traits::*;
-pub use device::DeviceExtManual;
-pub use device_manager::DeviceManagerExtManual;
-pub use drag_context::DragContextExtManual;
-pub use screen::ScreenExtManual;
-pub use visual::VisualExtManual;
+pub use cairo_interaction::ContextExt;
 pub use window::WindowExtManual;
